@@ -1,42 +1,29 @@
 /*
-*   Copyright (C) 2008 Nicola Gigante <nicola.gigante@gmail.com>
-*
-*   This program is free software; you can redistribute it and/or modify
-*   it under the terms of the GNU Lesser General Public License as published by
-*   the Free Software Foundation; either version 2.1 of the License, or
-*   (at your option) any later version.
-*
-*   This program is distributed in the hope that it will be useful,
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*   GNU General Public License for more details.
-*
-*   You should have received a copy of the GNU Lesser General Public License
-*   along with this program; if not, write to the
-*   Free Software Foundation, Inc.,
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
+    SPDX-FileCopyrightText: 2008 Nicola Gigante <nicola.gigante@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "../../policy-gen/policy-gen.h"
 
-#include <iostream>
 #include <Security/Security.h>
+#include <iostream>
+
+#include <QDebug>
 
 using namespace std;
 
-void output(QList<Action> actions, QMap<QString, QString> domain)
+void output(const QList<Action> &actions, const QMap<QString, QString> &domain)
 {
     AuthorizationRef auth;
-    AuthorizationCreate(NULL, NULL, kAuthorizationFlagDefaults, &auth);
+    AuthorizationCreate(NULL, kAuthorizationEmptyEnvironment, kAuthorizationFlagDefaults, &auth);
 
     OSStatus err;
 
-    foreach (const Action &action, actions) {
-
+    for (const Action &action : std::as_const(actions)) {
         err = AuthorizationRightGet(action.name.toLatin1().constData(), NULL);
 
-        if (err == errAuthorizationDenied) {
-
+        if (err != errAuthorizationSuccess) {
             QString rule;
 
             if (action.policy == QLatin1String("yes")) {
@@ -50,12 +37,15 @@ void output(QList<Action> actions, QMap<QString, QString> domain)
             }
 
             CFStringRef cfRule = CFStringCreateWithCString(NULL, rule.toLatin1().constData(), kCFStringEncodingASCII);
-            CFStringRef cfPrompt = CFStringCreateWithCString(NULL, action.descriptions.value(QLatin1String("en")).toLatin1().constData(), kCFStringEncodingASCII);
+            CFStringRef cfPrompt =
+                CFStringCreateWithCString(NULL, action.descriptions.value(QLatin1String("en")).toLatin1().constData(), kCFStringEncodingASCII);
 
             err = AuthorizationRightSet(auth, action.name.toLatin1().constData(), cfRule, cfPrompt, NULL, NULL);
             if (err != noErr) {
                 cerr << "You don't have the right to edit the security database (try to run cmake with sudo): " << err << endl;
                 exit(1);
+            } else {
+                qInfo() << "Created or updated rule" << rule << "for right entry" << action.name << "policy" << action.policy << "; domain=" << domain;
             }
         }
     }
