@@ -2,6 +2,7 @@
     SPDX-FileCopyrightText: 2008 Nicola Gigante <nicola.gigante@gmail.com>
     SPDX-FileCopyrightText: 2009 Radek Novacek <rnovacek@redhat.com>
     SPDX-FileCopyrightText: 2009-2010 Dario Freddi <drf@kde.org>
+    SPDX-FileCopyrightText: 2023 Kai Uwe Broulik <kde@broulik.de>
 
     SPDX-License-Identifier: LGPL-2.1-or-later
 */
@@ -17,6 +18,8 @@
 
 #include <PolkitQt1/Authority>
 
+#include <memory>
+
 class QByteArray;
 
 namespace KAuth
@@ -43,6 +46,9 @@ private Q_SLOTS:
     void checkForResultChanged();
 
 private:
+    void sendWindowHandle(const QString &action, const QString &handle);
+    void sendActivationToken(const QString &action, QWindow *window);
+
     QHash<QString, Action::AuthStatus> m_cachedResults;
 };
 
